@@ -62,7 +62,10 @@ class RepositoryPath():
     Repos = "/var/db/pkg"
     Calculate = path.join(Repos, "calculate")
     Distros = path.join(Repos, "distros")
-    Gentoo = '/usr/portage'
+    if os.path.isdir('/var/db/repos/gentoo'):
+        Gentoo = '/var/db/repos/gentoo'
+    else:
+        Gentoo = '/usr/portage'
     CalculateProfiles = path.join(Calculate, "profiles")
     CalculateTemplates = path.join(CalculateProfiles, "templates")
 
